# Multi-Precision Arithmetic

LibRapid has support for [MPIR](https://github.com/wbhart/mpir) and [MPFR](https://www.mpfr.org/), which support
arbitrary-precision integers, floating points and rationals.

We provide a simple wrapper around these libraries, enabling all mathematical operations to be performed on
these data types -- you don't even need to use a different function name!

```{toctree}
:hidden:
Multi-Precision Listing <multiPrecisionListing>
```
